==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/bitmap-win.h <==
//$Id: bitmap-win.h,v 1.3 2004/01/25 12:28:09 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_BITMAP_WIN_H
#define GUIKACHU_BITMAP_WIN_H

#include "bitmap-res.h"
#include "resource-win.h"

#include <gtk--/window.h>
#include <gtk--/optionmenu.h>
#include <gtk--/pixmap.h>

namespace Guikachu
{
    namespace GUI
    {
	class BitmapWindow: public ResourceWindow,
			    public SigC::Object
	{
	    Resources::Bitmap *res;
	    
	    Gtk::Window        window;	    
	    Gtk::OptionMenu    type_combo;
            Gtk::Pixmap        preview_pixmap;

            Gtk::Button       *export_button;

	public:
	    BitmapWindow (Resources::Bitmap *res);
	    void show ();
            
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();
            void update_image ();

	    void type_menu_cb (Resources::Bitmap::BitmapType type);
	    bool update_block;

            void load_image_cb ();
	    void export_image_cb ();
	};
    }
}

#endif /* !GUIKACHU_BITMAP_WIN_H */

==> guikachu-1.5.7.tar.gz: guikachu-1.5.7/src/bitmap-win.h <==
//$Id: bitmap-win.h,v 1.8 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_BITMAP_WIN_H
#define GUIKACHU_BITMAP_WIN_H

#include "bitmap-res.h"
#include "resource-win.h"

#include <gtkmm/window.h>
#include <gtkmm/image.h>
#include <gtkmm/button.h>

namespace Guikachu
{
    namespace GUI
    {
	class BitmapWindow: public ResourceWindow,
			    public sigc::trackable
	{
	    Resources::Bitmap *res;
	    
	    Gtk::Window  window;	    
            Gtk::Image   preview_pixmap;
            Gtk::Button *export_button;

	public:
	    BitmapWindow (Resources::Bitmap *res);
	    void show ();
            
	private:
	    bool delete_event_impl (GdkEventAny *e);
	    void update ();
            void update_image ();

            void load_image_cb ();
	    void export_image_cb ();
	};
    }
}

#endif /* !GUIKACHU_BITMAP_WIN_H */
